import {
  select,
  csv,
  scaleBand,
  scaleLinear,
  extent,
  max,
  axisBottom,
  axisLeft,
  interval
} from 'd3';

const margin = {
  top: 30,
  right: 50,
  bottom: 120,
  left: 50,
};

const width =
  window.innerWidth - margin.right - margin.left;
const height =
  window.innerHeight - margin.top - margin.bottom;

const parseRow = (d) => {
  d.revenue = +d.revenue;
  d.profit = +d.profit;

  return d;
};

const svg = select('body')
  .append('svg')
  .attr(
    'width',
    width + margin.right + margin.left
  )
  .attr(
    'height',
    height + margin.top + margin.bottom
  );

const yValue = (d) => {
  return d.revenue;
};
const xValue = (d) => d.month;
const main = async () => {
  let data = await csv('revenues.csv', parseRow);

  const x = scaleBand()
    .domain(data.map(xValue))
    .range([0, width])
    .paddingInner(0.1)
    .paddingOuter(0.2);

  const y = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([height, 0]);

  const marks = data.map((d) => {
    return {
      x: x(xValue(d)),
      y: y(yValue(d)),
    };
  });

  const xAxis = axisBottom(x);
  const yAxis = axisLeft(y);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${margin.top})`
    );

  g.selectAll('rect')
    .data(marks)
    .join('rect')
    .attr('width', (d) => x.bandwidth())
    .attr('height', (d) => height - d.y)
    .attr('y', (d) => d.y)
    .attr('x', (d) => d.x)
    .attr('fill', '#4682b4');
  
  while(true){
  svg.selectAll
  }

  xAxis(
    g
      .append('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(0,  ${height})`
      )
      .call(xAxis)
  );

  yAxis(
    g
      .append('g')
      .attr('class', 'y-axis')
      .call(yAxis)
  );

  //x-label
  g.append('text')
    .attr('class', 'x-label')
    .attr('x', width / 2)
    .attr('y', height + 110)
    .attr('font-size', '20px')
    .attr('text-anchor', 'middle')
    .text('Monthly Revenue');
};


main();
